#include <QDir>
#include <QDesktopServices>

#include "ConfigGuiOpts.h"

ConfigGuiOpts::ConfigGuiOpts()
{
    /* The gui configuration file is located in ~/.config/NNTPGrab/nntpgrab_gui.conf */
    QString path;
    QString filename;
#ifdef WIN32
    path = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + QString("\\NNTPGrab");
    filename = path + QString("\\nntpgrab_gui.conf");
#else
    path = QDir::homePath() + QString("/.config/NNTPGrab");
    filename = path + QString("/nntpgrab_gui.conf");
#endif

    /* Create the path if it doesn't exists yet */
    QDir d("/");
    d.mkpath(path);

    settings = new QSettings(filename, QSettings::IniFormat);

    /* Set default values if some parameter isn't set yet */
    setShowNotificationOnFileDownloaded(getShowNotificationOnFileDownloaded());
    setShowNotificationOnFileDecoded(getShowNotificationOnFileDecoded());
    setShowTrayIcon(getShowTrayIcon());
    setHostname1(getHostname1());
    setHostname2(getHostname2());
    setHostname3(getHostname3());
    setHostname4(getHostname4());
    setHostname5(getHostname5());
    setShowColumnProgress(getShowColumnProgress());
    setShowColumnSubject(getShowColumnSubject());
    setShowColumnPoster(getShowColumnPoster());
    setShowColumnNewsgroups(getShowColumnNewsgroups());
    setShowColumnFilesize(getShowColumnFilesize());
    setShowColumnFilesizeRemaining(getShowColumnFilesizeRemaining());
    setShowColumnStamp(getShowColumnStamp());
    setShowColumnTimeRemaining(getShowColumnTimeRemaining());
    setShowColumnTimeToFinish(getShowColumnTimeToFinish());
    setAutoImportDirectory(getAutoImportDirectory());
    setEnableAutoImport(getEnableAutoImport());
    setLastUsedNzbDirectory(getLastUsedNzbDirectory());
    setShowConnectDialog(getShowConnectDialog());
    setAutoLoadPlugins(getAutoLoadPlugins());
    setHideInactiveConnections(getHideInactiveConnections());
}

ConfigGuiOpts::~ConfigGuiOpts()
{
    delete settings;
}

bool ConfigGuiOpts::getShowNotificationOnFileDownloaded() const
{
    return settings->value("options/show_notification_on_file_downloaded", FALSE).toBool();
}

void ConfigGuiOpts::setShowNotificationOnFileDownloaded(bool showNotificationOnFileDownloaded)
{
    settings->setValue("options/show_notification_on_file_downloaded", showNotificationOnFileDownloaded);
}

bool ConfigGuiOpts::getShowNotificationOnFileDecoded() const
{
    return settings->value("options/show_notification_on_file_decoded", FALSE).toBool();
}

void ConfigGuiOpts::setShowNotificationOnFileDecoded(bool showNotificationOnFileDecoded)
{
    settings->setValue("options/show_notification_on_file_decoded", showNotificationOnFileDecoded);
}

bool ConfigGuiOpts::getShowTrayIcon() const
{
#ifdef Q_OS_DARWIN
    return settings->value("options/show_tray_icon", FALSE).toBool();
#else
    return settings->value("options/show_tray_icon", TRUE).toBool();
#endif
}

void ConfigGuiOpts::setShowTrayIcon(bool showTrayIcon)
{
    settings->setValue("options/show_tray_icon", showTrayIcon);
}

QString ConfigGuiOpts::getHostname1() const
{
    return settings->value("options/hostname1", "localhost").toString();
}

void ConfigGuiOpts::setHostname1(QString hostname1)
{
    settings->setValue("options/hostname1", hostname1);
}

QString ConfigGuiOpts::getHostname2() const
{
    return settings->value("options/hostname2", "").toString();
}

void ConfigGuiOpts::setHostname2(QString hostname2)
{
    settings->setValue("options/hostname2", hostname2);
}

QString ConfigGuiOpts::getHostname3() const
{
    return settings->value("options/hostname3", "").toString();
}

void ConfigGuiOpts::setHostname3(QString hostname3)
{
    settings->setValue("options/hostname3", hostname3);
}

QString ConfigGuiOpts::getHostname4() const
{
    return settings->value("options/hostname4", "").toString();
}

void ConfigGuiOpts::setHostname4(QString hostname4)
{
    settings->setValue("options/hostname4", hostname4);
}

QString ConfigGuiOpts::getHostname5() const
{
    return settings->value("options/hostname5", "").toString();
}

void ConfigGuiOpts::setHostname5(QString hostname5)
{
    settings->setValue("options/hostname5", hostname5);
}

bool ConfigGuiOpts::getShowColumnProgress() const
{
    return settings->value("options/show_column_progress", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnProgress(bool showColumnProgress)
{
    settings->setValue("options/show_column_progress", showColumnProgress);
}

bool ConfigGuiOpts::getShowColumnSubject() const
{
    return settings->value("options/show_column_subject", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnSubject(bool showColumnSubject)
{
    settings->setValue("options/show_column_subject", showColumnSubject);
}

bool ConfigGuiOpts::getShowColumnPoster() const
{
    return settings->value("options/show_column_poster", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnPoster(bool showColumnPoster)
{
    settings->setValue("options/show_column_poster", showColumnPoster);
}

bool ConfigGuiOpts::getShowColumnNewsgroups() const
{
    return settings->value("options/show_column_newsgroups", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnNewsgroups(bool showColumnNewsgroups)
{
    settings->setValue("options/show_column_newsgroups", showColumnNewsgroups);
}

bool ConfigGuiOpts::getShowColumnFilesize() const
{
    return settings->value("options/show_column_filesize", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnFilesize(bool showColumnFilesize)
{
    settings->setValue("options/show_column_filesize", showColumnFilesize);
}

bool ConfigGuiOpts::getShowColumnFilesizeRemaining() const
{
    return settings->value("options/show_column_filesize_remaining", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnFilesizeRemaining(bool showColumnFilesizeRemaining)
{
    settings->setValue("options/show_column_filesize_remaining", showColumnFilesizeRemaining);
}

bool ConfigGuiOpts::getShowColumnStamp() const
{
    return settings->value("options/show_column_stamp", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnStamp(bool showColumnStamp)
{
    settings->setValue("options/show_column_stamp", showColumnStamp);
}

bool ConfigGuiOpts::getShowColumnTimeRemaining() const
{
    return settings->value("options/show_column_time_remaining", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnTimeRemaining(bool showColumnTimeRemaining)
{
    settings->setValue("options/show_column_time_remaining", showColumnTimeRemaining);
}

bool ConfigGuiOpts::getShowColumnTimeToFinish() const
{
    return settings->value("options/show_column_time_to_finish", TRUE).toBool();
}

void ConfigGuiOpts::setShowColumnTimeToFinish(bool showColumnTimeToFinish)
{
    settings->setValue("options/show_column_time_to_finish", showColumnTimeToFinish);
}

QString ConfigGuiOpts::getAutoImportDirectory() const
{
    QString path;

#ifdef Q_OS_WIN32
    path = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/NNTPGrab/NZB";
#else
    path = QDesktopServices::storageLocation(QDesktopServices::HomeLocation) + "/NNTPGrab/NZB";
#endif

    /* Create the path if it doesn't exists yet */
    QDir d("/");
    d.mkpath(path);

    return settings->value("options/auto_import_directory", path).toString();
}

void ConfigGuiOpts::setAutoImportDirectory(QString autoImportDirectory)
{
    QDir d("/");
    if (!d.exists(autoImportDirectory)) {
        return;
    }

    settings->setValue("options/auto_import_directory", autoImportDirectory);
}

bool ConfigGuiOpts::getEnableAutoImport() const
{
    return settings->value("options/enable_auto_import", FALSE).toBool();
}

void ConfigGuiOpts::setEnableAutoImport(bool enableAutoImport)
{
    settings->setValue("options/enable_auto_import", enableAutoImport);
}

QString ConfigGuiOpts::getLastUsedNzbDirectory() const
{
    return settings->value("options/last_used_nzb_directory", "").toString();
}

void ConfigGuiOpts::setLastUsedNzbDirectory(QString lastUsedNzbDirectory)
{
    settings->setValue("options/last_used_nzb_directory", lastUsedNzbDirectory);
}

bool ConfigGuiOpts::getShowConnectDialog() const
{
    return settings->value("options/show_connect_dialog", TRUE).toBool();
}

void ConfigGuiOpts::setShowConnectDialog(bool showConnectDialog)
{
    settings->setValue("options/show_connect_dialog", showConnectDialog);
}

QStringList ConfigGuiOpts::getAutoLoadPlugins() const
{
    QStringList ret = settings->value("options/auto_load_plugins", "").toStringList();

    /* The list may contain empty elements, strip these out */
    for (int i = ret.count() - 1; i >= 0; i--) {
        QString s = ret.at(i);
        if (s.isEmpty()) {
            ret.removeAt(i);
        }
    }
    return ret;
}

void ConfigGuiOpts::setAutoLoadPlugins(QStringList autoLoadPlugins)
{
    settings->setValue("options/auto_load_plugins", autoLoadPlugins);
}

bool ConfigGuiOpts::getHideInactiveConnections() const
{
    return settings->value("options/hide_inactive_connections", FALSE).toBool();
}

void ConfigGuiOpts::setHideInactiveConnections(bool hideInactiveConnections)
{
    settings->setValue("options/hide_inactive_connections", hideInactiveConnections);
}

QByteArray ConfigGuiOpts::getGeometry(QString objectName) const
{
    return settings->value("View/geometry_"+objectName).toByteArray();
}

void ConfigGuiOpts::setGeometry(QString objectName, QByteArray geometry)
{
    settings->setValue("View/geometry_"+objectName, geometry);
}

QByteArray ConfigGuiOpts::getState(QString objectName) const
{
    return settings->value("View/state_"+objectName).toByteArray();
}

void ConfigGuiOpts::setState(QString objectName, QByteArray state)
{
    settings->setValue("View/state_"+objectName, state);
}

int ConfigGuiOpts::getCurrentTabIndex() const
{
    return settings->value("View/currentTabIndex").toInt();
}

void ConfigGuiOpts::setCurrentTabIndex(int index)
{
    settings->setValue("View/currentTabIndex", index);
}

