#ifndef DOWNLOADQUEUEMODEL_H
#define DOWNLOADQUEUEMODEL_H

#include <QAbstractItemModel>
#include "QNNTPGrabGlue.h"
#include "DownloadQueueItem.h"

class DownloadQueueModel : public QAbstractItemModel
{
    Q_OBJECT
public:
    DownloadQueueModel(QNNTPGrabGlue *glue, QObject *parent = 0);
    ~DownloadQueueModel();

    QVariant data(const QModelIndex &index, int role) const;
    Qt::ItemFlags flags(const QModelIndex &index) const;
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
    QModelIndex parent(const QModelIndex &index) const;
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    int columnCount(const QModelIndex &parent = QModelIndex()) const;

    DownloadQueueItem *itemForIndex(const QModelIndex &index) const;

private:
    void loadDownloadQueue(QNNTPGrabGlue *glue);
    int calculateProgress(quint64 size, quint64 sizeRemaining);
    DownloadQueueItem *lookupCollectionItem(QString collection_name);
    DownloadQueueItem *lookupSubjectItem(DownloadQueueItem *collection_item, QString subject);

    DownloadQueueItem *rootItem;

private slots:
    void onFileDownloadStateUpdate(QString collection_name, QString subject, int num_parts_total, int num_parts_done, int num_parts_failed, quint64 file_size, quint64 file_size_remaining, quint64 total_size, quint64 total_size_remaining);
    void onFileStateChanged(QString collection_name, QString subject, QString real_filename, QNNTPGrabGlue::TaskState old_state, QNNTPGrabGlue::TaskState new_state, quint64 file_size_remaining, quint64 total_size, quint64 total_size_remaining);

    void onFileAdded(QString collection_name, QString subject, QString poster, QDateTime stamp, quint64 file_size, quint64 total_size, quint64 total_size_remaining, QNNTPGrabGlue::TaskState state, int num_parts, QList<QString> groups);
    void onFileRemoved(QString collection_name, QString subject, quint64 total_size, quint64 total_size_remaining);
    void onFileMoved(QString orig_collection_name, QString subject, QString new_collection_name, int old_position, int new_position);

    void onCollectionAdded(QString collection_name, QString poster);
    void onCollectionRemoved(QString collection_name);
    void onCollectionModified(QString collection_name, QString poster);
    void onCollectionMoved(QString collection_name, int old_position, int new_position);

    void onTrafficMonitorUpdate(int bytes_received1, int bytes_received2, int bytes_received3, int bytes_received4, int bytes_received5, int bytes_received6, int bytes_received7, int bytes_received8, int bytes_received9, int bytes_received10, QDateTime stamp, double average);

signals:
    void requestColumnResize(DownloadQueueItem::field column);

public slots:

};

#endif // DOWNLOADQUEUEMODEL_H
