#include "nntpgrab_utils.h"
#include "QNZBCreator.h"

QNZBCreator::QNZBCreator(QObject *parent) :
    QObject(parent)
{
}

bool QNZBCreator::checkApiVersion(bool &api_okay, QString &errmsg)
{
    bool ret_tmp;
    ngboolean api_okay_tmp = FALSE;
    char *errmsg_tmp = NULL;

    ret_tmp = nntpgrab_utils_nzbcreator_check_api_version(&api_okay_tmp, &errmsg_tmp);

    if (!ret_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return false;
    }

    api_okay = (bool) api_okay_tmp;
    return true;
}

bool QNZBCreator::getMaintenanceInfo(QString &errmsg, QNZBCreator::MaintenanceInfo &maintenance_info)
{
    NZBCreatorMaintenanceInfo *info_tmp;
    char *errmsg_tmp = NULL;

    info_tmp = nntpgrab_utils_nzbcreator_get_maintenance_info(&errmsg_tmp);
    if (!info_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return false;
    }

    maintenance_info.down_for_maintenance = info_tmp->down_for_maintenance;
    maintenance_info.reason = info_tmp->reason;

    nntpgrab_utils_nzbcreator_free_maintenance_info(info_tmp);

    return true;
}

bool QNZBCreator::getAllGroups(QString &errmsg, QList<QNZBCreator::Group> &groups)
{
    char *errmsg_tmp = NULL;
    NGList *groups_tmp, *list;
    QNZBCreator::Group group;

    errmsg.clear();
    groups.clear();

    groups_tmp = nntpgrab_utils_nzbcreator_get_all_groups(&errmsg_tmp);
    if (!groups_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return false;
    }

    list = groups_tmp;
    while (list) {
        NZBCreatorGroup *group_tmp = (NZBCreatorGroup*) list->data;

        group.group_id = group_tmp->group_id;
        group.newsgroup = group_tmp->newsgroup;
        groups.append(group);

        list = ng_list_next(list);
    }

    nntpgrab_utils_nzbcreator_free_groups(groups_tmp);
    return TRUE;
}

bool QNZBCreator::performSearch(QNZBCreator::SearchOpts opts, QString &errmsg, QNZBCreator::SearchResult &result)
{
    char *errmsg_tmp = NULL;
    NZBCreatorSearchOpts opts_tmp;
    NZBCreatorSearchResult *result_tmp;

    memset(&opts_tmp, 0, sizeof(NZBCreatorSearchResult));
    strncpy(opts_tmp.query, opts.query.toUtf8(), sizeof(opts_tmp.query) - 1);
    strncpy(opts_tmp.username, opts.username.toUtf8(), sizeof(opts_tmp.username) - 1);
    strncpy(opts_tmp.password, opts.password.toUtf8(), sizeof(opts_tmp.password) - 1);
    opts_tmp.search_only_in = (NZBCreatorSearchOnlyIn) opts.search_only_in;
    opts_tmp.max_age = opts.max_age;
    opts_tmp.minimal_file_size = opts.minimal_file_size;
    opts_tmp.maximal_file_size = opts.maximal_file_size;
    opts_tmp.percentage_complete = opts.percentage_complete;
    opts_tmp.group_to_search = opts.group_to_search;
    opts_tmp.file_type = (NNTPFileType) opts.file_type;
    opts_tmp.offset = opts.offset;

    result_tmp = nntpgrab_utils_nzbcreator_perform_search(opts_tmp, &errmsg_tmp);
    if (!result_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return false;
    }

    result.number_of_hits = result_tmp->number_of_hits;
    result.number_of_results = result_tmp->number_of_results;
    result.results_per_page = result_tmp->results_per_page;
    result.offset = result_tmp->offset;

    NGList *list = result_tmp->collections;
    while (list) {
        NZBCreatorCollection *collection_tmp = (NZBCreatorCollection*) list->data;
        QNZBCreator::Collection collection;

        collection.collection_id = collection_tmp->collection_id;
        collection.collection_name = collection_tmp->collection_name;
        collection.short_collection_name = collection_tmp->short_collection_name;
        collection.poster = collection_tmp->poster;
        collection.newsgroup = collection_tmp->newsgroup;
        collection.stamp = QDateTime::fromTime_t(collection_tmp->stamp);
        collection.total_size = collection_tmp->total_size;
        collection.num_parts_found = collection_tmp->num_parts_found;
        collection.num_parts_expected = collection_tmp->num_parts_expected;
        collection.complete_percentage = collection_tmp->complete_percentage;
        collection.num_regular_files = collection_tmp->num_regular_files;
        collection.num_par2_files = collection_tmp->num_par2_files;
        collection.first_file_id = collection_tmp->first_file_id;

        result.collections.append(collection);

        list = ng_list_next(list);
    }

    nntpgrab_utils_nzbcreator_free_result(result_tmp);
    return true;
}

bool QNZBCreator::retrieveAdditionalCollectionDetails(qint64 collection_id, QDateTime stamp, QString &errmsg, QList<QNZBCreator::File> &result)
{
    char *errmsg_tmp = NULL;
    NGList *files_tmp;

    files_tmp = nntpgrab_utils_nzbcreator_retrieve_collection_details((ngint64) collection_id, (time_t) stamp.toTime_t(), &errmsg_tmp);
    if (!files_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return false;
    }

    NGList *list = files_tmp;
    while (list) {
        NZBCreatorFile *file_tmp = (NZBCreatorFile*) list->data;
        QNZBCreator::File file;

        file.file_id = file_tmp->file_id;
        file.subject = file_tmp->subject;
        file.poster = file_tmp->poster;
        file.stamp = QDateTime::fromTime_t(file_tmp->stamp);
        file.file_size = file_tmp->file_size;
        file.file_type = (QNZBCreator::FileType) file_tmp->file_type;
        file.complete_percentage = file_tmp->complete_percentage;
        file.num_parts_found = file_tmp->num_parts_found;
        file.num_parts_expected = file_tmp->num_parts_expected;

        result.append(file);

        list = ng_list_next(list);
    }

    nntpgrab_utils_nzbcreator_free_collection_details(files_tmp);
    return true;
}

QString QNZBCreator::generateNZB(QList<int> file_ids, QDateTime oldest_stamp, QDateTime newest_stamp, QString &errmsg)
{
    NGList *file_ids_tmp = NULL;
    char *errmsg_tmp = NULL;
    char *result_tmp;

    Q_FOREACH(int file_id, file_ids) {
        file_ids_tmp = ng_list_append(file_ids_tmp, (void*) (int)file_id);
    }

    result_tmp = nntpgrab_utils_nzbcreator_generate_NZB(file_ids_tmp, (time_t) oldest_stamp.toTime_t(), (time_t) newest_stamp.toTime_t(), &errmsg_tmp);
    ng_list_free(file_ids_tmp);
    if (!result_tmp) {
        errmsg = errmsg_tmp;
        ng_free(errmsg_tmp);
        return QString();
    } else {
        QString result = result_tmp;
        ng_free(result_tmp);
        return result;
    }
}
