#include "WidgetConfigDisplay.h"
#include "ui_WidgetConfigDisplay.h"
#include "ConfigGuiOpts.h"
#include "mainwindow.h"

WidgetConfigDisplay::WidgetConfigDisplay(WidgetConnections *widgetConnections, WidgetDownloadQueue *widgetDownloadQueue, MainWindow *mainwindow, QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WidgetConfigDisplay)
{
    ui->setupUi(this);

    this->widgetConnections = widgetConnections;
    this->widgetDownloadQueue = widgetDownloadQueue;
    this->mainwindow = mainwindow;

    if (opts.getShowColumnProgress()) {
        ui->chkShowColumnProgress->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_STATE_STR);
    }

    if (opts.getShowColumnSubject()) {
        ui->chkShowColumnSubject->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_SUBJECT);
    }

    if (opts.getShowColumnPoster()) {
        ui->chkShowColumnPoster->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_POSTER);
    }

    if (opts.getShowColumnNewsgroups()) {
        ui->chkShowColumnNewsgroups->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_GROUPS);
    }

    if (opts.getShowColumnFilesize()) {
        ui->chkShowColumnFileSize->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_FILE_SIZE_STR);
    }

    if (opts.getShowColumnFilesizeRemaining()) {
        ui->chkShowColumnFileSizeRemaining->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_FILE_SIZE_REMAINING_STR);
    }

    if (opts.getShowColumnStamp()) {
        ui->chkShowColumnStamp->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_STAMP);
    }

    if (opts.getShowColumnTimeRemaining()) {
        ui->chkShowColumnTimeRemaining->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_ESTIMATED_TIME_REMAINING_STR);
    }

    if (opts.getShowColumnTimeToFinish()) {
        ui->chkShowColumnTimeToFinish->setChecked(true);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_ESTIMATED_TIME_TO_FINISH_STR);
    }

    if (opts.getShowTrayIcon()) {
        ui->chkShowTrayIcon->setChecked(true);
    }
    if (opts.getShowConnectDialog()) {
        ui->chkShowConnectDialog->setChecked(true);
    }
    if (opts.getHideInactiveConnections()) {
        ui->chkHideInactiveConnections->setChecked(true);
    }

    connect(ui->chkShowColumnProgress, SIGNAL(toggled(bool)), SLOT(chkShowColumnProgress_toggled(bool)));
    connect(ui->chkShowColumnSubject, SIGNAL(toggled(bool)), SLOT(chkShowColumnSubject_toggled(bool)));
    connect(ui->chkShowColumnPoster, SIGNAL(toggled(bool)), SLOT(chkShowColumnPoster_toggled(bool)));
    connect(ui->chkShowColumnNewsgroups, SIGNAL(toggled(bool)), SLOT(chkShowColumnNewsgroups_toggled(bool)));
    connect(ui->chkShowColumnFileSize, SIGNAL(toggled(bool)), SLOT(chkShowColumnFileSize_toggled(bool)));
    connect(ui->chkShowColumnFileSizeRemaining, SIGNAL(toggled(bool)), SLOT(chkShowColumnFileSizeRemaining_toggled(bool)));
    connect(ui->chkShowColumnStamp, SIGNAL(toggled(bool)), SLOT(chkShowColumnStamp_toggled(bool)));
    connect(ui->chkShowColumnTimeRemaining, SIGNAL(toggled(bool)), SLOT(chkShowColumnTimeRemaining_toggled(bool)));
    connect(ui->chkShowColumnTimeToFinish, SIGNAL(toggled(bool)), SLOT(chkShowColumnTimeToFinish_toggled(bool)));

    connect(ui->chkShowTrayIcon, SIGNAL(toggled(bool)), SLOT(chkShowTrayIcon_toggled(bool)));
    connect(ui->chkShowConnectDialog, SIGNAL(toggled(bool)), SLOT(chkShowConnectDialog_toggled(bool)));
    connect(ui->chkHideInactiveConnections, SIGNAL(toggled(bool)), SLOT(chkHideInactiveConnections_toggled(bool)));
}

WidgetConfigDisplay::~WidgetConfigDisplay()
{
    delete ui;
}

void WidgetConfigDisplay::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void WidgetConfigDisplay::chkShowColumnProgress_toggled(bool toggled)
{
    opts.setShowColumnProgress(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_STATE_STR);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_STATE_STR);
    }
}

void WidgetConfigDisplay::chkShowColumnSubject_toggled(bool toggled)
{
    opts.setShowColumnSubject(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_SUBJECT);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_SUBJECT);
    }
}

void WidgetConfigDisplay::chkShowColumnPoster_toggled(bool toggled)
{
    opts.setShowColumnPoster(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_POSTER);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_POSTER);
    }
}

void WidgetConfigDisplay::chkShowColumnNewsgroups_toggled(bool toggled)
{
    opts.setShowColumnNewsgroups(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_GROUPS);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_GROUPS);
    }
}

void WidgetConfigDisplay::chkShowColumnFileSize_toggled(bool toggled)
{
    opts.setShowColumnFilesize(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_FILE_SIZE_STR);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_FILE_SIZE_STR);
    }
}

void WidgetConfigDisplay::chkShowColumnFileSizeRemaining_toggled(bool toggled)
{
    opts.setShowColumnFilesizeRemaining(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_FILE_SIZE_REMAINING_STR);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_FILE_SIZE_REMAINING_STR);
    }
}

void WidgetConfigDisplay::chkShowColumnStamp_toggled(bool toggled)
{
    opts.setShowColumnStamp(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_STAMP);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_STAMP);
    }
}

void WidgetConfigDisplay::chkShowColumnTimeRemaining_toggled(bool toggled)
{
    opts.setShowColumnTimeRemaining(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_ESTIMATED_TIME_REMAINING_STR);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_ESTIMATED_TIME_REMAINING_STR);
    }
}

void WidgetConfigDisplay::chkShowColumnTimeToFinish_toggled(bool toggled)
{
    opts.setShowColumnTimeToFinish(toggled);
    if (toggled) {
        widgetDownloadQueue->showField(DownloadQueueItem::FIELD_ESTIMATED_TIME_TO_FINISH_STR);
    } else {
        widgetDownloadQueue->hideField(DownloadQueueItem::FIELD_ESTIMATED_TIME_TO_FINISH_STR);
    }
}

void WidgetConfigDisplay::chkShowTrayIcon_toggled(bool toggled)
{
    opts.setShowTrayIcon(toggled);
    if (toggled) {
        mainwindow->showTrayIcon();
    } else {
        mainwindow->hideTrayIcon();
    }
}

void WidgetConfigDisplay::chkShowConnectDialog_toggled(bool toggled)
{
    opts.setShowConnectDialog(toggled);
}

void WidgetConfigDisplay::chkHideInactiveConnections_toggled(bool toggled)
{
    opts.setHideInactiveConnections(toggled);
    widgetConnections->reloadGuiOpts();
}
