#include <QPainter>
#include <QFont>

#include "WidgetTrafficMonitor.h"
#include "ui_WidgetTrafficMonitor.h"

WidgetTrafficMonitor::WidgetTrafficMonitor(QNNTPGrabGlue *glue, QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WidgetTrafficMonitor)
{
    ui->setupUi(this);

    memset(bytes_received, 0, sizeof(bytes_received));
    average = 0;
    stamp = QDateTime();

    this->glue = glue;
    connect(glue, SIGNAL(trafficMonitorUpdate(int,int,int,int,int,int,int,int,int,int,QDateTime,double)), SLOT(onTrafficMonitorUpdate(int,int,int,int,int,int,int,int,int,int,QDateTime,double)));

    setBackgroundRole(QPalette::Base);
    setAutoFillBackground(true);
}

WidgetTrafficMonitor::~WidgetTrafficMonitor()
{
    delete ui;
}

void WidgetTrafficMonitor::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void WidgetTrafficMonitor::paintEvent(QPaintEvent *e)
{
    Q_UNUSED(e);

    int i;
    int max = 0;
    double y_factor;
    int y_offset;
    double x, y;
    int max_height;

    /* Calculate the peak value */
    for (i = 0; i < 10; i++) {
        if (bytes_received[i] > max) {
            max = bytes_received[i];
        }
    }

    if (max == 0) {
        /* Nothing to draw yet */
        /* Just paint a black border */
        QPainter painter(this);
        painter.setRenderHint(QPainter::Antialiasing, false);
        painter.setPen(palette().dark().color());
        painter.setBrush(Qt::NoBrush);
        painter.drawRect(QRect(0, 0, width() - 1, height() - 2));
        return;
    }

    max_height = height() - (height() / 10);
    y_offset = height() / 10;
    y_factor = max_height;
    y_factor /= max;

    QPainter painter(this);
    painter.setPen(QPen(QColor(144, 179, 223)));
    painter.setBrush(QBrush(QColor(144, 179, 223)));
    painter.setRenderHint(QPainter::Antialiasing, true);

    /* Create a new path in which all coordinates are defined */
    QPainterPath path;

    /* Use the first coordinate as starting point */
    y = bytes_received[0];
    y *= y_factor;
    y = max_height - y;
    y += y_offset;
    path.moveTo(0, y);

    /* Create a path through the rest of the coordinates */
    for (i = 1; i < 10; i++) {
        x = width();
        x /= 9;
        x *= i;

        y = bytes_received[i];
        y *= y_factor;
        y = max_height - y;
        y += y_offset;

        path.lineTo(x, y);
    }

    /* Finalize the path by going to the bottom right corner */
    path.lineTo(width(), max_height + y_offset);

    /* and to the bottom left corner */
    path.lineTo(0, max_height + y_offset);

    /* Draw the path */
    painter.drawPath(path);

    /* Draw the average speed */
    QString msg = glue->utilsCalculateFileSize(average) + "/sec";
    QFont font("", 12);
    font = QFont(font, painter.device());
    QFontMetrics fontMetrics(font);
    painter.setBrush(Qt::NoBrush);
    painter.setPen(QPen(QColor(0, 0, 0)));
    painter.setFont(font);
    painter.drawText(width() - fontMetrics.width(msg) - 5, height() - 5, msg);

    /* Draw a small border around the graph */
    painter.setRenderHint(QPainter::Antialiasing, false);
    painter.setPen(palette().dark().color());
    painter.setBrush(Qt::NoBrush);
    painter.drawRect(QRect(0, 0, width() - 1, height() - 2));
}

void WidgetTrafficMonitor::onTrafficMonitorUpdate(int bytes_received1, int bytes_received2, int bytes_received3, int bytes_received4, int bytes_received5, int bytes_received6, int bytes_received7, int bytes_received8, int bytes_received9, int bytes_received10, QDateTime stamp, double average)
{
    /* TODO: Is this threadsafe? */
    this->bytes_received[0] = bytes_received1;
    this->bytes_received[1] = bytes_received2;
    this->bytes_received[2] = bytes_received3;
    this->bytes_received[3] = bytes_received4;
    this->bytes_received[4] = bytes_received5;
    this->bytes_received[5] = bytes_received6;
    this->bytes_received[6] = bytes_received7;
    this->bytes_received[7] = bytes_received8;
    this->bytes_received[8] = bytes_received9;
    this->bytes_received[9] = bytes_received10;
    this->average = average;
    this->stamp = stamp;

    update();
}
