/*
    Copyright (C) 2005-2012  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_GUI_BASE_H_
#define _NNTPGRAB_GUI_BASE_H_

#ifdef _MSC_VER
#include "config.h.win32"
#else
#include "config.h"
#endif

#include <glib/gi18n.h>
#include <gtk/gtk.h>

/**
 * nntpgrab_gui_base_create_ui:
 * @interface_filename:         The location of the interface file without the extension
 *
 * Build a user interface based on the .glade or (GtkBuilder) .ui file pointed to by @interface_filename
 */
void       nntpgrab_gui_base_create_ui(const char *interface_filename);

/**
 * nntpgrab_gui_base_destroy_ui:
 *
 * Destroy the loaded user interface
 */
void       nntpgrab_gui_base_destroy_ui(void);

/**
 * nntpgrab_gui_base_dialog_show:
 * @parent:             Parent window
 * @message:            The message which needs to be shown
 * @msg_type:           The type of the message (info/warning/error)
 * @btn_type:           The type of buttons which need to be shown in the dialog
 *
 * Show a notification dialog
 */
int        nntpgrab_gui_base_dialog_show(GtkWidget *parent, const char *message, GtkMessageType msg_type, GtkButtonsType btn_type);

/**
 * nntpgrab_gui_base_get_widget:
 * @name:                   The name of the widget which needs to be looked up
 *
 * Look up a widget in the user interface and return a pointer to it
 *
 * Returns:  (allow-none):  Pointer to the widget with the given @name or NULL if the widget could not be found
 */
GtkWidget *nntpgrab_gui_base_get_widget(const char *name);

/**
 * nntpgrab_gui_base_get_object:
 * @name:                   The name of the object which needs to be looked up
 *
 * Look up an object in the user interface and return a pointer to it
 *
 * Returns:   (allow-none):  Pointer to the object with the given @name of NULL if the object could not be found
 */
GObject   *nntpgrab_gui_base_get_object(const char *name);

/**
 * nntpgrab_gui_base_tray_create:
 *
 * Create a tray icon
 */
void             nntpgrab_gui_base_tray_create(void);

/**
 * nntpgrab_gui_base_tray_destroy:
 *
 * Destroy a tray icon
 */
void             nntpgrab_gui_base_tray_destroy(void);

/**
 * nntpgrab_gui_base_tray_icon_get_is_shown:
 *
 * Indicate whether a tray icon is being shown at the moment
 *
 * Returns:    TRUE if the tray icon is being shown
 */
gboolean         nntpgrab_gui_base_tray_icon_get_is_shown(void);

#if !GTK_CHECK_VERSION(2,10,0)
typedef void GtkStatusIcon;
#endif

/**
 * nntpgrab_gui_base_tray_get_status_icon:
 *
 * Return a pointer to a GtkStatusIcon
 *
 * Returns: a GtkStatusIcon
 */
GtkStatusIcon   *nntpgrab_gui_base_tray_get_status_icon(void);

#endif /* _NNTPGRAB_GUI_BASE_H_ */

