/*
    Copyright (C) 2005-2012  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _DOWNLOAD_QUEUE_H_
#define _DOWNLOAD_QUEUE_H_

#include "nntpgrab_plugin.h"
#include "configuration.h"
#include "collections.h"

gboolean     download_queue_init(Configuration *config, char **errmsg);
gboolean     download_queue_destroy(char **errmsg);
void         download_queue_reset_all_server_positions(void);
gboolean     download_queue_save(char **errmsg);
gboolean     download_queue_get_next_part_to_download(NNTPCollection **collection, NNTPFile **file, NNTPPart **part, int server_id, gboolean *nothing_to_download_or_active);
void         download_queue_update_part_status(const char *servername, int connection_id, NNTPCollection *collection, NNTPFile *file, NNTPPart *part, int server_id, gboolean success, gboolean reset_to_zero, gboolean dont_retry_anymore);
void         download_queue_check_if_files_are_ready_to_be_decoded(void);
gboolean     download_queue_test_is_decoding_still_needed(NNTPCollection *collection, NNTPFile *file);
void         download_queue_about_to_start_decoding(NNTPCollection *collection, NNTPFile *file);
void         download_queue_mark_file_as_decoded_and_unref(NNTPCollection *collection, NNTPFile *file, const char *real_filename, NGTaskState status);
gboolean     download_queue_add_file_to_queue(const char *collection_name, const char *subject, const char *poster, time_t stamp, nguint64 file_size, NGList *groups, NGList *parts, char **errmsg);
gboolean     download_queue_del_file_from_queue(const char *collection_name, const char *subject, char **errmsg);
gboolean     download_queue_restart_file(const char *collection_name, const char *subject, char **errmsg);
void         download_queue_foreach_file(ForeachCollectionFunc collection_func, ForeachFileFunc file_func, ForeachGroupFunc group_func, gpointer data);
gboolean     download_queue_move_file(const char *collection_name_src, const char *subject_src, const char *collection_name_dest, int position_dest);
gboolean     download_queue_move_collection(const char *collection_name, int new_position);
gboolean     download_queue_mark_task_optional(const char *collection_name, const char *subject, gboolean is_optional);
void         download_queue_download_smallest_par2_files(NNTPCollection *collection);
void         download_queue_test_is_collection_downloaded(NNTPCollection *collection);
void         download_queue_test_if_all_downloads_are_completed(void);
void         download_queue_on_par2_repair_failure(NGPlugin *plugin_data, int num_params, const char **params, gpointer data);

#endif /* _DOWNLOAD_QUEUE_H_ */
