/*
    Copyright (C) 2005-2012  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_INTERNAL_H_
#define _NNTPGRAB_INTERNAL_H_

#include <glib/gi18n.h>

#include "nntpgrab_types.h"

void     core_signals_clear_stack(void);

void     nntpgrab_core_emit_config_changed(gboolean direct);
void     nntpgrab_core_emit_all_downloads_completed(gboolean direct);
void     nntpgrab_core_emit_connecting(gboolean direct, const char *servername, int conn_id);
void     nntpgrab_core_emit_connected(gboolean direct, const char *servername, int conn_id, const char *welcome_msg);
void     nntpgrab_core_emit_disconnect(gboolean direct, const char *servername, int conn_id, NNTPDisconnectType disconnect_type, const char *errmsg);
void     nntpgrab_core_emit_traffic_monitor_update(gboolean direct, int bytes_received[10], time_t stamp);
void     nntpgrab_core_emit_part_progress_update(gboolean direct, const char *servername, int conn_id, const char *collection_name, const char *subject, int part_num, int bytes_downloaded, int bytes_total);
void     nntpgrab_core_emit_part_download_start(gboolean direct, const char *servername, int conn_id, const char *collection_name, const char *subject, int part_num);
void     nntpgrab_core_emit_part_done(gboolean direct, const char *servername, int conn_id, const char *collection_name, const char *subject, int part_num, int size);
void     nntpgrab_core_emit_part_failed(gboolean direct, const char *servername, int conn_id, const char *collection_name, const char *subject, int part_num, int size, gboolean all_servers_tried);
void     nntpgrab_core_emit_collection_added(gboolean direct, const char *collection_name, const char *poster);
void     nntpgrab_core_emit_collection_removed(gboolean direct, const char *collection_name);
void     nntpgrab_core_emit_collection_modified(gboolean direct, const char *collection_name, const char *poster);
void     nntpgrab_core_emit_file_added(gboolean direct, const char *collection_name, const char *subject, const char *poster, guint64 stamp, guint64 file_size, guint64 total_size, guint64 total_size_remaining, NGTaskState status, int num_parts, GList *groups);
void     nntpgrab_core_emit_file_removed(gboolean direct, const char *collection_name, const char *subject, guint64 total_file_size, guint64 total_file_size_remaining);
void     nntpgrab_core_emit_file_download_state_update(gboolean direct, const char *collection_name, const char *subject, int num_parts_total, int num_parts_done, int num_parts_failed, guint64 file_size, guint64 file_size_remaining, guint64 total_size, guint64 total_size_remaining);
void     nntpgrab_core_emit_file_state_changed(gboolean direct, const char *collection_name, const char *subject, const char *real_filename, NGTaskState old_state, NGTaskState new_state, guint64 file_size_remaining, guint64 total_size, guint64 total_size_remaining);
void     nntpgrab_core_emit_schedular_state_changed(gboolean direct, NGSchedularState state, const char *reason);
void     nntpgrab_core_emit_file_moved(gboolean direct, const char *orig_collection_name, const char *subject, const char *new_collection_name, int old_position, int new_position);
void     nntpgrab_core_emit_collection_moved(gboolean direct, const char *collection_name, int old_position, int new_position);
void     nntpgrab_core_emit_collection_downloaded(gboolean direct, const char *collection_name);
void     nntpgrab_core_emit_log_message(gboolean direct, const char *component, NGLogLevel log_level, const char *message, gboolean emit_to_frontend, gboolean emit_to_plugins);
void     nntpgrab_core_emit_plugin_loaded(gboolean direct, const char *plugin_name, gboolean is_persistent);
void     nntpgrab_core_emit_plugin_unloaded(gboolean direct, const char *plugin_name);
void     nntpgrab_core_emit_plugin_event(gboolean direct, const char *plugin_name, const char *event_name, const char **params);

#endif /* _NNTPGRAB_INTERNAL_H_ */
